@@ -26,6 +26,7 @@ from .title import should_save_title, save_title
 from .favicon import should_save_favicon, save_favicon
 from .wget import should_save_wget, save_wget
 from .singlefile import should_save_singlefile, save_singlefile
+from .readability import should_save_readability, save_readability
 from .pdf import should_save_pdf, save_pdf
 from .screenshot import should_save_screenshot, save_screenshot
 from .dom import should_save_dom, save_dom
@@ -42,6 +43,7 @@ def get_default_archive_methods():
             ('pdf', should_save_pdf, save_pdf),
             ('screenshot', should_save_screenshot, save_screenshot),
             ('dom', should_save_dom, save_dom),
+            ('readability', should_save_readability, save_readability), #keep readability below wget and singlefile, as it depends on them
             ('git', should_save_git, save_git),
             ('media', should_save_media, save_media),
             ('archive_org', should_save_archive_dot_org, save_archive_dot_org),
@@ -93,6 +95,7 @@ def archive_link(link: Link, overwrite: bool=False, methods: Optional[Iterable[s
                     stats[result.status] += 1
                     log_archive_method_finished(result)
                 else:
+                    print('      X {}'.format(method_name))
                     stats['skipped'] += 1
             except Exception as e:
                 raise Exception('Exception in archive_methods.save_{}(Link(url={}))'.format(
